@@ -64,6 +64,9 @@ def create(project_name: str = typer.Argument("magic-server"), replace: bool = F
 
 @app.command()
 def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
+    prefix = getattr(sys, "prefix", "")
+    print("prefix", prefix)
+
     main_filename = "main.py"
     if not Path(main_filename).exists():
         typer.echo(
@@ -74,15 +77,14 @@ def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
     command = f"export LOCAL=1 && python {main_filename}"
 
     prefix = getattr(sys, "prefix", "")
+    print("prefix", prefix)
     if venv_name not in prefix and create_venv:
         typer.echo(
             "No venv is active, will check to see if one exists and make one if not."
         )
         venv_path = Path(venv_name)
         if not venv_path.exists():
-            print("VENV PATH", venv_path)
-            print("cwd", Path.cwd())
-            print("dir", os.listdir())
+            typer.echo(f"No venv detected, will make one now with name {venv_name}")
             make_venv(venv_name)
         command = f"source {venv_name}/bin/activate && {command}"
 
@@ -91,7 +93,7 @@ def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
 
 @app.command()
 def version():
-    typer.echo("7")
+    typer.echo("8")
 
 
 if __name__ == "__main__":
